OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Zapouzdřená zpráva %s",
    "Important mail" : "Důležité e-maily",
    "No message found yet" : "Zatím nenalezeny žádné zprávy",
    "Set up an account" : "Nastavit si účet",
    "Unread mail" : "Nepřečtené e-maily",
    "Important" : "Důležité",
    "Work" : "Pracovní",
    "Personal" : "Osobní",
    "To Do" : "Úkoly",
    "Later" : "Později",
    "Mail" : "E-mail",
    "You are reaching your mailbox quota limit for {account_email}" : "Blížíte se limitu kvóty objemu dat vaší e-mailové schránky u účtu {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Nyní využíváte {percentage} úložiště vaší e-mailové schránky. Uvolněte nějaké místo smazáním nepotřebných e-mailů.",
    "Mail Application" : "Aplikace pro e-mail",
    "Mails" : "E-maily",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "E-mail odesilatele: %1$s není v adresáři kontaktů, ale jméno odesilatele: %2$s se v adresáři kontaktů vyskytuje s následujícím e-mailem: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "E-mail odesilatele: %1$s není v adresáři kontaktů, ale jméno odesilatele: %2$s se v adresáři kontaktů vyskytuje s následujícími e-maily: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Odesilatel používá přizpůsobený e-mail: %1$s namísto e-mailu odesilatele: %2$s",
    "Sent date is in the future" : "Datum odeslání se nachází v budoucnosti",
    "Some addresses in this message are not matching the link text" : "Některé adresy v této zprávě se neshodují s textem odkazu",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "E-mail na který odpovídat: %1$s se liší od e-mailu odesilatele: %2$s",
    "Mail connection performance" : "Výkon připojení k e-mailu",
    "Slow mail service detected (%1$s) an attempt to connect to several accounts took an average of %2$s seconds per account" : "Zjištěna pomalá e-mailová služba (%1$s) pokus o připojení k několika účtům zabral průměrně %2$s sekund na účet",
    "Slow mail service detected (%1$s) an attempt to perform a mail box list operation on several accounts took an average of %2$s seconds per account" : "Zjištěna pomalá e-mailová služba (%1$s) pokus o provedení výpisu seznamu e-mailů na několika účtech zabral průměrně %2$s sekund na účet",
    "Mail Transport configuration" : "Nastavení transportu e-mailů",
    "The app.mail.transport setting is not set to smtp. This configuration can cause issues with modern email security measures such as SPF and DKIM because emails are sent directly from the web server, which is often not properly configured for this purpose. To address this, we have discontinued support for the mail transport. Please remove app.mail.transport from your configuration to use the SMTP transport and hide this message. A properly configured SMTP setup is required to ensure email delivery." : "Nastavením app.mail.transport není smtp. Toto uspořádání může způsobovat problémy s moderními opatřeními pro zabezpečení e-mailů, jako je SPF a DKIM, protože e-maily jsou posílány přímo z web serveru, který často nebývá pro tento účel správně nastavený. Kvůli tomu jsme ukončili podporu pro transport e-mailů. Odeberte app.mail.transport ze svého nastavení, čímž bude použit SMTP transport toto hlášení zmizí. Pro zajištění doručování e-mailů je zapotřebí správně nastaveného SMTP.",
    "💌 A mail app for Nextcloud" : "💌 E-mailová aplikace pro Nextcloud",
    "Your session has expired. The page will be reloaded." : "Platnost vaší relace skončila. Stránka bude znovu načtena.",
    "Drafts are saved in:" : "Koncepty jsou ukládány do:",
    "Sent messages are saved in:" : "Odeslané zprávy jsou ukládány do:",
    "Deleted messages are moved in:" : "Smazané zprávy jsou přesouvány do:",
    "Archived messages are moved in:" : "Archivované zprávy jsou přesunuty do:",
    "Snoozed messages are moved in:" : "Odložené zprávy jsou přesouvány do:",
    "Junk messages are saved in:" : "Zprávy-odpad jsou ukládány v:",
    "Connecting" : "Připojuje se",
    "Reconnect Google account" : "Znovu připojit ke Google účtu",
    "Sign in with Google" : "Přihlásit se prostřednictvím Google účtu",
    "Reconnect Microsoft account" : "Znovu připojit k Microsoft účtu",
    "Sign in with Microsoft" : "Přihlásit se prostřednictvím Microsoft",
    "Save" : "Uložit",
    "Connect" : "Připojit",
    "Looking up configuration" : "Hledání nastavení",
    "Checking mail host connectivity" : "Kontrola připojení k hostiteli e-mailové služby",
    "Configuration discovery failed. Please use the manual settings" : "Objevení nastavení se nezdařilo. Prosím nastavte ručně",
    "Password required" : "Je třeba hesla",
    "Testing authentication" : "Vyzkoušení ověření",
    "Awaiting user consent" : "Čeká na souhlas uživatele",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Účet vytvořen. Řiďte se pokyny ve vyskakovacím okně ohledně propojení s vaším Google účtem",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Účet vytvořen. Řiďte se pokyny ve vyskakovacím okně ohledně propojení s vaším Microsoft účtem",
    "Loading account" : "Načítání účtu",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Účet zaktualizován. Řiďte se pokyny ve vyskakovacím okně ohledně propojení s vaším Google účtem",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Účet zaktualizován. Řiďte se pokyny ve vyskakovacím okně ohledně propojení s vaším Microsoft účtem",
    "Account updated" : "Účet zaktualizován",
    "IMAP server is not reachable" : "IMAP server není dosažitelný",
    "SMTP server is not reachable" : "SMTP server není dosažitelný",
    "IMAP username or password is wrong" : "Uživatelské jméno nebo heslo pro IMAP není správné",
    "SMTP username or password is wrong" : "Uživatelské jméno nebo heslo pro SMTP není správné",
    "IMAP connection failed" : "Vytvoření IMAP připojení se nezdařilo",
    "SMTP connection failed" : "Vytvoření SMTP připojení se nezdařilo",
    "Authorization pop-up closed" : "Vyskakovací okno s autorizací zavřeno",
    "Configuration discovery temporarily not available. Please try again later." : "Objevování nastavení není dočasně k dispozici. Zkuste to znovu později.",
    "There was an error while setting up your account" : "Při nastavování vašeho účtu došlo k chybě",
    "Auto" : "Automaticky",
    "Name" : "Název",
    "Mail address" : "E-mailová adresa",
    "name@example.org" : "jmeno@example.org",
    "Please enter an email of the format name@example.com" : "Zadejte e-mail ve formátu jmeno@example.com",
    "Password" : "Heslo",
    "Manual" : "Ruční",
    "IMAP Settings" : "Nastavení pro IMAP",
    "IMAP Host" : "IMAP hostitel",
    "IMAP Security" : "Zabezpečení IMAP",
    "None" : "Žádné",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP uživatel",
    "IMAP Password" : "IMAP heslo",
    "SMTP Settings" : "Nastavení SMTP",
    "SMTP Host" : "SMTP hostitel",
    "SMTP Security" : "Zabezpečení SMTP",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP uživatel",
    "SMTP Password" : "SMTP heslo",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Aby Google účet fungoval s touto aplikací, je třeba v něm zapnout dvoufaktorové ověřování a vytvořit tam heslo pro tuto aplikaci.",
    "Account settings" : "Nastavení účtu",
    "Aliases" : "Alternativní názvy",
    "Alias to S/MIME certificate mapping" : "Alternativní název mapování S/MIME certifikátu",
    "Signature" : "Podpis",
    "A signature is added to the text of new messages and replies." : "Podpis je přidán pod text nových zpráv a odpovědí.",
    "Writing mode" : "Režim zápisu",
    "Preferred writing mode for new messages and replies." : "Upřednostňovaný režim psaní pro nové zprávy a odpovědi.",
    "Default folders" : "Výchozí složky",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Složky které použít pro koncepty, odeslané, smazané, archivované a odpadní zprávy.",
    "Automatic trash deletion" : "Automatické mazání koše",
    "Days after which messages in Trash will automatically be deleted:" : "Dnů v Koši, po jejichž uplynutí bude automaticky smazáno:",
    "Autoresponder" : "Automatická odpověď",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatická odpověď na příchozí zprávy. Pokud vám někdo pošle vícero zpráv, tato automatická odpověď bude odeslána nanejvýš co 4 dny.",
    "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "Nástroj pro automatické odpovědi používá Sieve – skriptovací jazyk podporovaný mnoho poskytovateli e-mailů. Pokud si nejste jistí, zda i ten vámi využívaný, dotažte se u něho. Pokud je Sieve k dispozici, klikněte na tlačítko pro přechod do nastavení a zapněte ho.",
    "Go to Sieve settings" : "Přejít do nastavení Sieve",
    "Filters" : "Filtry",
    "Sieve script editor" : "Editor sieve skriptů",
    "Mail server" : "E-mailový server",
    "Sieve server" : "Sieve server",
    "Mailbox search" : "Hledání ve schránce",
    "Update alias" : "Aktualizovat alternativní název",
    "Rename alias" : "Přejmenovat alternativní název",
    "Show update alias form" : "Zobrazit formulář pro aktualizaci alternativního názvu",
    "Delete alias" : "Smazat alternativní název",
    "Go back" : "Jít zpět",
    "Change name" : "Změnit název",
    "Email address" : "E-mailová adresa",
    "Add alias" : "Přidat alternativní název",
    "Create alias" : "Vytvořit alternativní název",
    "Cancel" : "Storno",
    "Search in the body of messages in priority Inbox" : "Hledat v těle zpráv v prioritní schránce",
    "Activate" : "Aktivovat",
    "Put my text to the bottom of a reply instead of on top of it." : "Můj text umístit na konec odpovědi namísto na její začátek.",
    "Mark as important" : "Označit jako důležité",
    "Remind about messages that require a reply but received none" : "Připomínat zprávy, na které je třeba odpovědět ale doposud se tak nestalo",
    "Use internal addresses" : "Použít vnitřní adresu",
    "Could not update preference" : "Prioritu se nedaří aktualizovat",
    "Mail settings" : "Nastavení pro E-mail",
    "Accounts" : "Účty",
    "Add mail account" : "Přidat e-mailový účet",
    "Settings for:" : "Nastavení pro:",
    "General" : "Obecné",
    "Layout" : "Rozvržení",
    "List" : "Seznam",
    "Vertical split" : "Svislé rozdělení",
    "Horizontal split" : "Vodorovné rozdělen",
    "Sorting" : "Řazení",
    "Newest" : "Nejnovější",
    "Oldest" : "Nejstarší",
    "Search in body" : "Hledat v těle",
    "Reply text position" : "Pozice textu odpovědi",
    "Gravatar settings" : "Nastavení pro gravatar",
    "Use Gravatar and favicon avatars" : "Použít Gravatar a favicon avatary",
    "Mailto" : "Příjemce",
    "Register as application for mail links" : "Zaregistrovat jako aplikaci pro obsluhu e-mailových odkazů",
    "Register" : "Registrovat",
    "Privacy and security" : "Soukromí a zabezpečení",
    "Data collection consent" : "Souhlas se shromažďováním dat",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Povolit aplikaci shromažďovat data o vaší interakci s ní. Na základě těchto dat se aplikace přizpůsobí vašim preferencím. Data budou ukládána pouze lokálně.",
    "Trusted senders" : "Důvěryhodní odesílatelé",
    "Internal addresses" : "Vnitřní adresy",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Zvýrazňovat externí e-mailové adresy zapnutím této funkce, spravovat vaše interní adresy a domény a zajistit tak, že rozpoznané kontakty zůstanou neoznačeny.",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "Spravovat S/MIME certifikáty",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain!" : "Mailvelope je pro stávající doménu zapnuté!",
    "Looking for a way to encrypt your emails?" : "Hledáte způsob jak šifrovat své e-maily?",
    "Install Mailvelope browser extension by clicking here" : "Kliknutím sem si nainstalujte rozšíření pro webový prohlížeč Mailvelope",
    "Enable Mailvelope for the current domain" : "Zapnout Mailvelope pro stávající doménu",
    "Assistance features" : "Funkce asistence",
    "About" : "O aplikaci",
    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Tato aplikace obsahuje CKEditor – opensource editor. Autorská práva © přispěvatelé do projektu CKEditor. Licencováno pod GPLv2.",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Compose new message" : "Napsat novou zprávu",
    "Newer message" : "Novější zpráva",
    "Older message" : "Starší zpráva",
    "Toggle star" : "Přidat/odebrat hvězdičku",
    "Toggle unread" : "Označit jako přečtené/nepřečtené",
    "Archive" : "Archiv",
    "Delete" : "Smazat",
    "Search" : "Hledat",
    "Send" : "Odeslat",
    "Refresh" : "Načíst znovu",
    "No certificate" : "Žádný certifikát",
    "Certificate updated" : "Certifikát aktualizován",
    "Could not update certificate" : "Certifikát se nepodařilo aktualizovat",
    "{commonName} - Valid until {expiryDate}" : "{commonName} – platný dol {expiryDate}",
    "Select an alias" : "Vyberte alternativní název",
    "Select certificates" : "Vybrat certifikát",
    "Update Certificate" : "Aktualizovat certifikát",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "Zvolený certifikát není serverem považován za důvěryhodný. Může se stát, že příjemci nebudou moci váš podpis ověřit.",
    "Encrypt with S/MIME and send later" : "Zašifrovat pomocí S/MIME a odeslat později",
    "Encrypt with S/MIME and send" : "Zašifrovat pomocí S/MIME a odeslat",
    "Encrypt with Mailvelope and send later" : "Zašifrovat pomocí Mailvelope a odeslat později",
    "Encrypt with Mailvelope and send" : "Zašifrovat pomocí Mailvelope a odeslat",
    "Send later" : "Odeslat později",
    "Message {id} could not be found" : "Zprávu {id} nelze najít",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Bylo vybráno podepsání či šifrování pomocí S/MIME, ale pro zvolený alternativní název není k dispozici certifikát. Tato zpráva nebude podepsána či šifrována.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Jakékoli existující formátování (např. tučné, skloněné, podtržené nebo obrázky v textu) bude odebráno.",
    "Turn off formatting" : "Vypnout formátování",
    "Turn off and remove formatting" : "Vypnout a odebrat formátování",
    "Keep formatting" : "Ponechat formátování",
    "From" : "Od",
    "Select account" : "Vybrat účet",
    "To" : "Pro",
    "Cc/Bcc" : "Kopie / skrytá kopie",
    "Select recipient" : "Vybrat příjemce",
    "Contact or email address …" : "Kontakt nebo e-mailová adresa…",
    "Cc" : "Kopie",
    "Bcc" : "Skrytá kopie",
    "Subject" : "Předmět",
    "Subject …" : "Předmět…",
    "This message came from a noreply address so your reply will probably not be read." : "Tato zpráva pochází z adresy noreply (neodpovídat), takže vaše odpověď pravděpodobně nebude přečtena.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Následující příjemci nemají S/MIME certifikát: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Následující příjemci nemají PGP klíč: {recipients}.",
    "Write message …" : "Napsat zprávu…",
    "Saving draft …" : "Ukládání konceptu…",
    "Error saving draft" : "Chyba při ukládání konceptu",
    "Draft saved" : "Koncept uložen",
    "Save draft" : "Uložit koncept",
    "Discard & close draft" : "Zahodit a zavřít koncept",
    "Enable formatting" : "Povolit formátování",
    "Disable formatting" : "Odebrat formátování",
    "Upload attachment" : "Nahrát přílohu",
    "Add attachment from Files" : "Přidat přílohu ze Souborů",
    "Add share link from Files" : "Přidat odkaz na sdílení ze Souborů",
    "Smart picker" : "Inteligentní výběr",
    "Request a read receipt" : "Vyžádat potvrzení o přečtení",
    "Sign message with S/MIME" : "Podepsat zprávu pomocí S/MIME",
    "Encrypt message with S/MIME" : "Zašifrovat zprávu pomocí S/MIME",
    "Encrypt message with Mailvelope" : "Zašifrovat zprávu pomocí Mailvelope",
    "Send now" : "Odeslat nyní",
    "Tomorrow morning" : "Zítra ráno",
    "Tomorrow afternoon" : "Zítra odpoledne",
    "Monday morning" : "V pondělí ráno",
    "Custom date and time" : "Uživatelsky určené datum a čas",
    "Enter a date" : "Zadejte datum",
    "Choose" : "Vybrat",
    "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
    "Choose a file to share as a link" : "Zvolte soubor, který sdílet jako odkaz",
    "_{count} attachment_::_{count} attachments_" : ["{count} příloha","{count} přílohy","{count} příloh","{count} přílohy"],
    "Untitled message" : "Zpráva bez názvu",
    "Expand composer" : "Rozbalit dialog psaní",
    "Close composer" : "Zavřít dialog psaní",
    "Confirm" : "Potvrdit",
    "Tag: {name} deleted" : "Štítek: {name} smazán",
    "An error occurred, unable to delete the tag." : "Došlo k chybě, štítek se nepodařilo smazat.",
    "The tag will be deleted from all messages." : "Štítek bude smazán ze všech zpráv.",
    "Plain text" : "Neformátovaný text",
    "Rich text" : "Formátovaný text",
    "No messages in this mailbox" : "V této schránce nejsou žádné zprávy",
    "No messages" : "Žádné zprávy",
    "Blind copy recipients only" : "Pouze příjemci skryté kopie",
    "No subject" : "Žádný předmět",
    "Later today – {timeLocale}" : "Později dnes – {timeLocale}",
    "Set reminder for later today" : "Nastavit připomínku na později dnes",
    "Tomorrow – {timeLocale}" : "Zítra – {timeLocale}",
    "Set reminder for tomorrow" : "Nastavit připomínku na zítra",
    "This weekend – {timeLocale}" : "Tento víkend – {timeLocale}",
    "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
    "Next week – {timeLocale}" : "Příští týden – {timeLocale}",
    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
    "No trash mailbox configured" : "Není nastavena žádná složka pro Koš",
    "Could not delete message" : "Zprávu se nedaří smazat",
    "Could not archive message" : "Zprávu se nedaří archivovat",
    "Thread was snoozed" : "Vlákno bylo odloženo",
    "Could not snooze thread" : "Vlákno se nepodařilo odložit",
    "Thread was unsnoozed" : "Odložení vlákna bylo zrušeno",
    "Could not unsnooze thread" : "Nepodařilo se zrušit odložení vlákna",
    "Draft: " : "Koncept:",
    "This summary was AI generated" : "Toto shrnutí bylo vytvořeno AI",
    "Encrypted message" : "Šifrovaná zpráva",
    "This message is unread" : "Tato zpráva je nepřečtená",
    "Unfavorite" : "Odebrat z oblíbených",
    "Favorite" : "Přidat do oblíbených",
    "Unread" : "Nastavit jako nepřečtené",
    "Read" : "Nastavit jako přečtené",
    "Unimportant" : "Označit jako nedůležité",
    "Mark not spam" : "Zrušit označení jako spam",
    "Mark as spam" : "Označit jako spam",
    "Edit tags" : "Upravit štítky",
    "Snooze" : "Odložit",
    "Unsnooze" : "Zrušit odložení",
    "Move thread" : "Přesunout vlákno",
    "Archive thread" : "Archivovat vlákno",
    "Delete thread" : "Smazat vlákno",
    "More actions" : "Další akce",
    "Back" : "Zpět",
    "Set custom snooze" : "Nastavit uživatelsky uživatelsky určené odložení",
    "Edit as new message" : "Upravit jako novou zprávu",
    "Create event" : "Vytvořit událost",
    "Create task" : "Vytvořit úkol",
    "Download message" : "Stáhnout si zprávu",
    "Load more" : "Načíst více",
    "_Mark {number} read_::_Mark {number} read_" : ["Označit {number} jako přečtený","Označit {number} jako přečtené","Označit {number} jako přečtené","Označit {number} jako přečtené"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Označit {number} jako nepřečtený","Označit {number} jako nepřečtené","Označit {number} jako nepřečtených","Označit {number} jako nepřečtené"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Označit {number} jako důležité","Označit {number} jako důležité","Označit {number} jako důležité","Označit {number} jako důležité"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených"],
    "_Favorite {number}_::_Favorite {number}_" : ["Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených"],
    "_Unselect {number}_::_Unselect {number}_" : ["Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Přesunout {number} vlákno","Přesunout {number} vlákna","Přesunout {number} vláken","Přesunout {number} vlákna"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Přeposlat {number} jako přílohu","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy"],
    "Report this bug" : "Nahlásit tuto chybu",
    "Event created" : "Událost vytvořena",
    "Could not create event" : "Událost se nedaří vytvořit",
    "All day" : "Celý den",
    "Select calendar" : "Vybrat kalendář",
    "Description" : "Popis",
    "Create" : "Vytvořit",
    "This event was updated" : "Tato událost byla zaktualizována",
    "{attendeeName} accepted your invitation" : "{attendeeName} přijal(a) vaši pozvánku",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} nezávazně přijal(a) vaši pozvánku",
    "{attendeeName} declined your invitation" : "{attendeeName} odmítl(a) vaši pozvánku",
    "{attendeeName} reacted to your invitation" : "{attendeeName} zareagoval(a) na vaši pozvánku",
    "Failed to save your participation status" : "Nepodařilo se uložit stav vaší účasti",
    "You accepted this invitation" : "Tuto pozvánku jste přijali",
    "You tentatively accepted this invitation" : "Tuto pozvánku jste nezávazně přijali",
    "You declined this invitation" : "Tuto pozvánku jste odmítli",
    "You already reacted to this invitation" : "Na tuto pozvánku už jste zareagovali",
    "You have been invited to an event" : "Byly jste pozvání do události",
    "This event was cancelled" : "Tato událost byla zrušena",
    "Save to" : "Uložit do",
    "Select" : "Vybrat",
    "Comment" : "Komentář",
    "Accept" : "Přijmout",
    "Decline" : "Odmítnout",
    "Tentatively accept" : "Nezávazně přijmout",
    "More options" : "Další volby",
    "This message has an attached invitation but the invitation dates are in the past" : "Tato zpráva má připojenou pozvánku, ale její datumy se nacházejí v minulosti",
    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "Tato zpráva má připojenou pozvánku, ale ta neobsahuje účastníka, který by odpovídal některé z adres nastavených e-mailových účtů",
    "Could not remove internal address {sender}" : "Nepodařilo odebrat vnitřní adresu {sender}",
    "Could not add internal address {address}" : "Nebylo možné přidat vnitřní adresu {address}",
    "individual" : "jednotlivé",
    "domain" : "doména",
    "Remove" : "Odebrat",
    "email" : "e-mail",
    "Add internal address" : "Přidat vnitřní adresu",
    "Add internal email or domain" : "Přidat interní e-mail nebo doménu",
    "Itinerary for {type} is not supported yet" : "Itinerář {type} zatím ještě není podporován",
    "To archive a message please configure an archive mailbox in account settings" : "Pokud chcete zprávu archivovat, nastavte si v účtu schránku pro archiv",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nejste oprávněni přesunout tuto zprávu do archivní složky a/nebo tuto zprávu smazat ze stávající složky",
    "Your IMAP server does not support storing the seen/unseen state." : "Vámi využívaný IMAP server nepodporuje ukládání stavu zobrazeno/nezobrazeno.",
    "Could not mark message as seen/unseen" : "Nebylo možné označit zprávu jako zobrazenou/nezobrazenou",
    "Could not open mailbox" : "Nedaří se otevřít e-mailovou schránku",
    "Loading messages …" : "Načítání zpráv…",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Vytváření rejstříku vašich zpráv. V případě rozsáhlejších e-mailových schránek toto může trvat poněkud déle.",
    "Choose target mailbox" : "Zvolte cílovou schránku",
    "No more submailboxes in here" : "Nejsou zde žádné další dílčí schránky",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Správy budou automaticky označené jako důležité v závislosti na tom, jakými správami jste se zabývali nebo označili jako důležité. Na začátku bude třeba měnit důležitost ručně a systém tak naučit, ale po čase se to zlepší.",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "Vámi zaslané zprávy, které vyžadují odpověď, ale ani po několika dnech se tak nestalo, se zobrazí zde.",
    "Follow up" : "Pokračování",
    "Follow up info" : "Informace o pokračování",
    "Important info" : "Důležité informace",
    "Other" : "Ostatní",
    "Could not send mdn" : "Mdn se nepodařilo odeslat",
    "The sender of this message has asked to be notified when you read this message." : "Odesílatel této zprávy Vás žádá o potvrzení přečtení této zprávy.",
    "Notify the sender" : "Odeslat potvrzení",
    "You sent a read confirmation to the sender of this message." : "Odesilateli jste poslali potvrzení o přečtení této zprávy.",
    "Message was snoozed" : "Zpráva byla odložena",
    "Could not snooze message" : "Zprávu se nepodařilo odložit",
    "Message was unsnoozed" : "Odložení zprávy bylo zrušeno",
    "Could not unsnooze message" : "Nepodařilo se zrušit odložení zprávy",
    "Forward" : "Přeposlat",
    "Move message" : "Přesunout zprávu",
    "Translate" : "Překládání",
    "Forward message as attachment" : "Přeposlat zprávu jako přílohu",
    "View source" : "Zobrazit zdroj",
    "Print message" : "Vytisknout zprávu",
    "Download thread data for debugging" : "Stáhnout si data vlákna pro účely ladění",
    "Message body" : "Tělo zprávy",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Varování: S/MIME podpis této zprávy není ověřen. Odesilatel  se může pokoušet vystupovat jako někdo jiný!",
    "Unnamed" : "Bez názvu",
    "Embedded message" : "Zapouzdřená zpráva",
    "Attachment saved to Files" : "Příloha uložena do Souborů",
    "Attachment could not be saved" : "Přílohu se nepodařilo uložit",
    "calendar imported" : "kalendář namimportován",
    "Choose a folder to store the attachment in" : "Vyberte složku pro uložení přílohy",
    "Import into calendar" : "Importovat do kalendáře",
    "Download attachment" : "Stáhnout si přílohu",
    "Save to Files" : "Uložit do Souborů",
    "Attachments saved to Files" : "Přílohy uloženy do Souborů",
    "Error while saving attachments" : "Chyba při ukládání příloh",
    "View fewer attachments" : "Zobrazit méně příloh",
    "Choose a folder to store the attachments in" : "Zvolte složku do které ukládat přílohy",
    "Save all to Files" : "Uložit vše do Souborů",
    "Download Zip" : "Stáhnout Zip soubor",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Zobrazit {count} další přílohu","Zobrazit {count} další přílohy","Zobrazit {count} dalších příloh","Zobrazit {count} další přílohy"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tato zpráva je zašifrovaná pomocí PGP. Pro její rozšifrování si nainstalujte doplněk Mailvelope.",
    "The images have been blocked to protect your privacy." : "Obrázky byly zablokovány z důvodu ochrany vašeho soukromí.",
    "Show images" : "Zobrazit obrázky",
    "Show images temporarily" : "Zobrazovat obrázky dočasně",
    "Always show images from {sender}" : "Od {sender} vždy obrázky zobrazit",
    "Always show images from {domain}" : "Z {domain} vždy obrázky zobrazit",
    "Message frame" : "Rámec zprávy",
    "Quoted text" : "Citovaný text",
    "Move" : "Přesunout",
    "Moving" : "Přesouvání",
    "Moving thread" : "Přesouvá se vlákno",
    "Moving message" : "Přesouvá se zpráva",
    "Loading …" : "Načítání…",
    "Not supported by the server" : "Nepodporováno serverem",
    "{usage} of {limit} used" : "využito {usage} z {limit}",
    "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "Schránku nebylo možné vytvořit. Název nejspíš obsahuje neplatné znaky. Zkuste jiný název.",
    "Remove account" : "Odebrat účet",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Účet pro {email} a data e-mailů, uložených v mezipaměti, budou odebrána z Nextcloud, ale ne z poskytovatele e-mailů.",
    "Remove {email}" : "Odebrat {email}",
    "Provisioned account is disabled" : "Předem připravený účet je deaktivován",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Prosíme aktivujte tento účet přihlášením se pomocí hesla. Stávající relace používá bezheslové ověření, např. sjednocené (SSO) nebo WebAuthn.",
    "Quota" : "Kvóta",
    "Show only subscribed mailboxes" : "Zobrazit pouze přihlášené poštovní schránky",
    "Add mailbox" : "Přidat schránku",
    "Mailbox name" : "Název schránky",
    "Saving" : "Ukládá se",
    "Move up" : "Přesunout výše",
    "Move down" : "Přesunout dolů",
    "Show all subscribed mailboxes" : "Zobrazit všechny přihlášené poštovní schránky",
    "Show all mailboxes" : "Zobrazit všechny schránky",
    "Collapse mailboxes" : "Sbalit schránky",
    "_{total} message_::_{total} messages_" : ["{total} zpráva","{total} zprávy","{total} zpráv","{total} zprávy"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepřečtený z {total}","{unread} nepřečtené z {total}","{unread} nepřečtených z {total}","{unread} nepřečtené z {total}"],
    "All messages in mailbox will be deleted." : "Veškeré zprávy ve schránce budou smazány.",
    "Clear mailbox {name}" : "Smazat schránku {name}",
    "Clear mailbox" : "Smazat schránku",
    "The mailbox and all messages in it will be deleted." : "Poštovní schránka a všechny zprávy v ní budou odstraněny.",
    "Delete mailbox" : "Smazat schránku",
    "Delete mailbox {name}" : "Smazat schránku {name}",
    "An error occurred, unable to rename the mailbox." : "Došlo k chybě, schránku se nepodařilo přejmenovat.",
    "Please wait 10 minutes before repairing again" : "Počkejte 10 minut před opětovnou opravou",
    "Mark all as read" : "Označit vše jako přečtené",
    "Mark all messages of this mailbox as read" : "Označit všechny zprávy v této schránce jako přečtené",
    "Add submailbox" : "Přidat dílčí schránku",
    "Rename" : "Přejmenovat",
    "Move mailbox" : "Přesunout schránku",
    "Repair mailbox" : "Opravit schránku",
    "Clear cache" : "Vyprázdnit mezipaměť",
    "Clear locally cached data, in case there are issues with synchronization." : "V případě, že jsou problémy se synchronizací, vyčistěte data v místní mezipaměti.",
    "Subscribed" : "Přihlášeno se k odběru",
    "Sync in background" : "Synchronizace na pozadí",
    "Outbox" : "Odchozí pošta",
    "New message" : "Nová zpráva",
    "Edit message" : "Upravit zprávu",
    "Draft" : "Koncept",
    "Reply" : "Odpovědět",
    "Message saved" : "Zpráva uložena",
    "Failed to save message" : "Zprávu se nepodařilo uložit",
    "Failed to save draft" : "Koncept se nepodařilo uložit",
    "attachment" : "příloha",
    "attached" : "přiloženo",
    "No sent mailbox configured. Please pick one in the account settings." : "Není nastavená žádná složka pro odchozí. Zvolte nějakou v nastavení účtu.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "V kolonkách Pro a Skrytá kopie se snažíte poslat opravdu mnoha příjemcům. Zvažte použití Skryté kopie a nesdělování tak adres příjemců všem.",
    "Your message has no subject. Do you want to send it anyway?" : "Vaše zpráva nemá žádný předmět. Chcete ji i tak odeslat?",
    "You mentioned an attachment. Did you forget to add it?" : "Zmínili jste přílohu. Nezapomněli jste ji přidat?",
    "Message discarded" : "Zpráva zahozena",
    "Could not discard message" : "Zprávu se nepodařilo zahodit",
    "Maximize composer" : "Maximalizovat dialog editoru zprávy",
    "Show recipient details" : "Zobrazit podrobnosti o příjemci",
    "Hide recipient details" : "Skrýt podrobnosti o příjemci",
    "Minimize composer" : "Minimalizovat dialog psaní",
    "Error sending your message" : "Chyba při odesílání vaší zprávy",
    "Retry" : "Zkusit znovu",
    "Warning sending your message" : "Varování při odesílání vaší zprávy",
    "Send anyway" : "Poslat i tak",
    "Welcome to {productName} Mail" : "Vítejte v {productName} Poště",
    "Start writing a message by clicking below or select an existing message to display its contents" : "Kliknutím níže začněte psát zprávu nebo vyberte existující a zobrazte si její obsah",
    "Autoresponder off" : "Automatické odpovědi vypnuty",
    "Autoresponder on" : "Automatické odpovědi zapnuty",
    "Autoresponder follows system settings" : "Automatický odpovídač následuje nastavení systému",
    "The autoresponder follows your personal absence period settings." : "Automatický odpovídač následuje vaše osobní nastavení období nepřítomnosti",
    "Edit absence settings" : "Upravit nastavení nepřítomnosti",
    "First day" : "První den",
    "Last day (optional)" : "Poslední den (nepovinné)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} bude nahrazeno předmětem správy na kterou odpovídáte",
    "Message" : "Zpráva",
    "Oh Snap!" : "Kruci!",
    "Save autoresponder" : "Uložit automatickou odpověď",
    "Could not open outbox" : "Nepodaří se otevřít odchozí poštu",
    "Pending or not sent messages will show up here" : "Zprávy čekájící na odeslání a ty neodeslané se zobrazí zde",
    "Could not copy to \"Sent\" mailbox" : "Nebylo možné zkopírovat do složky „Odeslané“",
    "Mail server error" : "Chyba e-mailového serveru",
    "Message could not be sent" : "Zprávu se nepodařilo odeslat",
    "Message deleted" : "Zpráva smazána",
    "Copy to \"Sent\" Mailbox" : "Zkopírovat do složky „Odeslané“",
    "Copy to Sent Mailbox" : "Zkopírovat do složky Odeslané",
    "Phishing email" : "Phisingový e-mail",
    "This email might be a phishing attempt" : "Tento e-mail by mohl být pokusem o phishing",
    "Hide suspicious links" : "Skrýt podezřelé odkazy",
    "Show suspicious links" : "Zobrazit podezřelé odkazy",
    "link text" : "text odkazu",
    "Copied email address to clipboard" : "E-mailová adresa zkopírována do schránky",
    "Could not copy email address to clipboard" : "E-mailovou adresu se nepodařilo zkopírovat do schránky",
    "Contacts with this address" : "Kontakty s touto adresou",
    "Add to Contact" : "Přidat do kontaktů",
    "New Contact" : "Nový kontakt",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "Contact name …" : "Jméno kontaktu…",
    "Add" : "Přidat",
    "Show less" : "Zobrazit méně",
    "Show more" : "Zobrazit více",
    "Clear" : "Vyčistit",
    "Search in mailbox" : "Hledat ve schránce",
    "Close" : "Zavřít",
    "Search parameters" : "Parametry hledání",
    "Search subject" : "Hledat předmět",
    "Body" : "Těle textu",
    "Search body" : "Hledat v těle zprávy",
    "Date" : "Datum",
    "Pick a start date" : "Vybrat datum začátku",
    "Pick an end date" : "Vybrat datum konce",
    "Select senders" : "Vybrat odesilatele",
    "Select recipients" : "Vybrat příjemce",
    "Select CC recipients" : "Vybrat příjemce kopie",
    "Select BCC recipients" : "Vybrat příjemce slepé kopie",
    "Tags" : "Štítky",
    "Select tags" : "Výběr štítků",
    "Marked as" : "Označeno jako",
    "Has attachments" : "Má přílohy",
    "Mentions me" : "Zmiňuje mne",
    "Has attachment" : "Má přílohu",
    "Last 7 days" : "Uplynulých 7 dnů",
    "From me" : "Ode mne",
    "Enable mail body search" : "Zapnout hledání v těle zprávy",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve je mocný jazyk pro psaní filtrovacích pravidel pro e-mailovou schránku. Pokud je vámi využívaná e-mailová služba podporuje, je možné zpravovat sieve skripty v aplikaci E-mail. Sieve je také vyžadováno použít v automatických odpovědích a filtrech.",
    "Enable sieve filter" : "Zapnout sieve filtr",
    "Sieve host" : "Stroj se sieve",
    "Sieve security" : "Zabezpečení sieve",
    "Sieve Port" : "Port sieve",
    "Sieve credentials" : "Přihlašovací údaje do sieve",
    "IMAP credentials" : "Přihlašovací údaje k IMAP",
    "Custom" : "Uživatelsky určené",
    "Sieve User" : "Uživatel v sieve",
    "Sieve Password" : "Heslo do sieve",
    "Oh snap!" : "Kruci!",
    "Save sieve settings" : "Uložit nastavení pro sieve",
    "The syntax seems to be incorrect:" : "Syntaxe se nezdá být správná:",
    "Save sieve script" : "Uložit sieve skript",
    "Signature …" : "Podpis…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Váš podpis je větší než 2 MB. To může zpomalovat editor.",
    "Save signature" : "Uložit podpis",
    "Place signature above quoted text" : "Vložit podpis nad citovaný text",
    "An error occurred, unable to rename the tag." : "Došlo k chybě, štítek se nedaří přejmenovat.",
    "Edit name or color" : "Upravit název nebo barvu",
    "Saving new tag name …" : "Ukládání nového názvu štítku…",
    "Delete tag" : "Smazat štítek",
    "Set tag" : "Nastavit štítek",
    "Unset tag" : "Zrušit nastavení štítku",
    "Tag name is a hidden system tag" : "Takto nazvaný štítek už existuje v podobě skrytého systémového štítku",
    "Tag already exists" : "Štítek už existuje",
    "Tag name cannot be empty" : "Štítek je třeba nějak nazvat",
    "An error occurred, unable to create the tag." : "Došlo k chybě, štítek se nepodařilo vytvořit.",
    "Add default tags" : "Přidat výchozí štítky",
    "Add tag" : "Přidat štítek",
    "Saving tag …" : "Ukládání štítku…",
    "Task created" : "Úkol vytvořen",
    "Could not create task" : "Úkol se nezdařilo vytvořit",
    "No calendars with task list support" : "Nejsou zde žádné kalendáře, které by podporovaly seznam úkolů",
    "Summarizing thread failed." : "Shrnutí vlákna se nezdařilo.",
    "Could not load your message thread" : "Nepodařilo se načíst vlákno s danou zprávou",
    "The thread doesn't exist or has been deleted" : "Vlákno neexistuje nebo bylo smazáno",
    "Email was not able to be opened" : "E-mail nebylo možné otevřít",
    "Print" : "Tisk",
    "Loading thread" : "Načítání vlákna",
    "Not found" : "Nenalezeno",
    "Encrypted & verified " : "Šifrováno a ověřen",
    "Signature verified" : "Podpis ověřen",
    "Signature unverified " : "Podpis neověřen",
    "This message was encrypted by the sender before it was sent." : "Tato zpráva byla před odesláním zašifrována odesilatelem.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Tato zpráva obsahuje ověřený digitílní S/MIME podpis. Zpráva tedy nebyla od odeslání změněna.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Tato zpráva obsahuje neověřený digitální S/MIME podpis. Zpráva tedy mohla být po odeslání změněna nebo není certifikát podepisujícího považován za důvěryhodný.",
    "Reply all" : "Odpovědět všem",
    "Unsubscribe request sent" : "Požadavek na zrušení přihlášení se k oběru odeslán",
    "Could not unsubscribe from mailing list" : "Nepodařilo se zrušit přihášení k odběru e-mailové distribuce",
    "Please wait for the message to load" : "Vyčkejte na načtení zprávy",
    "Disable reminder" : "Vypnout připomínku",
    "Unsubscribe" : "Zrušit přihlášení k odběru",
    "Reply to sender only" : "Odpovědět pouze odesílateli",
    "Mark as unfavorite" : "Zrušit označení jako oblíbeného",
    "Mark as favorite" : "Označit jako oblíbené",
    "Mark as unread" : "Označit jako nepřečtené",
    "Mark as read" : "Označit jako přečtené",
    "Archive message" : "Archivovat zprávu",
    "Delete message" : "Smazat zprávu",
    "Message source" : "Zdrojový kód zprávy",
    "Unsubscribe via link" : "Zrušit (prostřednictvím odkazu) přihlášení se k odběru",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Zrušení přihlášení se k odběru zastaví veškeré zprávy  z e-mailové distribuce {sender}",
    "Send unsubscribe email" : "Odeslat e-mail ohledně zrušení odběru",
    "Unsubscribe via email" : "Zrušit (prostřednictvím e-mailu) přihlášení se k odběru",
    "{name} Assistant" : "{name} asistent",
    "Go to latest message" : "Přejít na poslední zprávu",
    "Go to newest message" : "Přejít na nejnovější zprávu",
    "Thread summary" : "Shrnutí vlákna",
    "Please select languages to translate to and from" : "Vyberte jazyk z kterého a do kterého překládat",
    "The message could not be translated" : "Zprávu se nepodařilo přeložit",
    "Translation copied to clipboard" : "Překlad zkopírován do schránky",
    "Translation could not be copied" : "Překlad se nepodařilo zkopírovat",
    "Translate message" : "Přeložit zprávu",
    "Source language to translate from" : "Zdrojový jazyk, ze kterého přeložit",
    "Translate from" : "Přeložit z",
    "Target language to translate into" : "Cílový jazyk, do kterého přeložit",
    "Translate to" : "Přeložit do",
    "Translating" : "Překládá se",
    "Copy translated text" : "Zkopírovat přeložený text",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Pokud chcete ponechávání v koši vypnout, kolonku nevyplňujte nebo zadejte hodnotu 0 (nula). Zpracovány budou pouze ty e-maily, smazaná po zapnutí ponechávání v koši.",
    "Could not remove trusted sender {sender}" : "Nepodařilo se odebrat důvěryhodného odesílatele {sender}",
    "No senders are trusted at the moment." : "V tuto chvíli nejsou mezi důvěryhodnými žádní odesílatelé.",
    "Untitled event" : "Nepojmenovaná událost",
    "(organizer)" : "(organizátor(ka))",
    "Import into {calendar}" : "Importovat do {calendar}",
    "Event imported into {calendar}" : "Událost importována do {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} z {depAirport} do {arrAirport}",
    "Airplane" : "Letadlo",
    "Reservation {id}" : "Rezervace {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} z {depStation} do {arrStation}",
    "Train from {depStation} to {arrStation}" : "Vlak z {depStation} do {arrStation}",
    "Train" : "Vlak",
    "Delete action" : "Akce smazání",
    "Flag" : "Vlajka",
    "The stop action ends all processing" : "Akce stop ukončí veškeré zpracovávání",
    "Delete filter" : "Smazat filtr",
    "Delete mail filter {filterName}?" : "Smazat filtr e-mailů {filterName}?",
    "Are you sure to delete the mail filter?" : "Opravdu chcete tento filtr smazat?",
    "New filter" : "Nový filtr",
    "Filter saved" : "Filtr uložen",
    "Could not save filter" : "Filtr se nepodařilo uložit",
    "Filter deleted" : "Filtr smazán",
    "Could not delete filter" : "Filtr se nepodařilo smazat",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Zkroťte chaos ve svých e-mailech. Filtry vám pomohou vypíchnout co je důlečité a eliminovat nepořádek.",
    "Filter is active" : "Filtr je aktivní",
    "Filter is not active" : "Filtr není aktivní",
    "Operator" : "Operátor",
    "If all tests pass, then the actions will be executed" : "Pokud veškeré testy projdou, pak budou akce vykonány",
    "If one test pass, then the actions will be executed" : "Pokud jeden test projde, pak budou akce vykonány",
    "Delete test" : "Smazat test",
    "Update mail filter" : "Zaktualizovat filtr e-mailů",
    "Filter name" : "Název filtru",
    "Tests" : "Testy",
    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Testy jsou uplatňovány na příchozí e-maily na vašem e-mailovém serveru, cílí na kolonky jako např. předmět (tj. řádek předmět e-mailu), od (odesilate) a pro (příjemce). Pro definování podmínek pro tyto kolonky je monžé použít následující operátory:",
    "An exact match. The field must be identical to the provided value." : "Přesná shoda. Je třeba, aby obsah kolonky přesně stejný, jako zadaná hodnota.",
    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Shoda v části řetězce. Kolonka odpovídá, pokud je v ní zadaná hodnota obsažena. Například „hlášení“ by se shodoval s „hláš“.",
    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Shoda s řetězcem pomocí zástupných znaků. Symbol „*“ (hvězdička) představuje libovolný počet znaků (včetně žádného), zatímco „?“ (otazník) odpovídá přesně jednomu znaku. Například, „hlášení*“ by se shodovalo s „hlášení o podníkání 2024“.",
    "New test" : "Nový test",
    "Actions" : "Akce",
    "Actions are triggered when the specified tests are true. The following actions are available:" : "Akce jsou spouštěny pokud jsou splněny zadané testy. K dispozici jsou následující akce:",
    "Moves the message into a specified folder." : "Přesune zprávu do zadané složky.",
    "Adds a flag to the message." : "Přidá zprávě příznak.",
    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Zastaví vykonávání filtrovacího skriptu. Po této akci nebudou zpracovávány žádné další filtry.",
    "New action" : "Nová akce",
    "Priority" : "Priorita",
    "Enable filter" : "Zapnout filtr",
    "Save filter" : "Uložit filtr",
    "Successfully updated config for \"{domain}\"" : "Úspěšně zaktualizováno nastavení pro „{domain}“",
    "Error saving config" : "Chyba při ukládání nastavení",
    "Saved config for \"{domain}\"" : "Uloženo nastavení pro „{domain}“",
    "Could not save provisioning setting" : "Nedaří se uložit nastavení pro zprovoznění služby",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Úspěšně zprovozněn {count} účet.","Úspěšně zprovozněny {count} účty.","Úspěšně zprovozněno {count} účtů.","Úspěšně zprovozněny {count} účty."],
    "There was an error when provisioning accounts." : "Při zprovozňování služby pro účty došlo k chybě.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Úspěšně smazány a zrušeno zprovoznění účtů pro „{domain}“",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Chyba při mazání a rušení zprovoznění účtů pro „{domain}“",
    "Could not save default classification setting" : "Nepodařilo se uložit výchozí nastavení rozřazování",
    "Mail app" : "E-mailová aplikace",
    "The mail app allows users to read mails on their IMAP accounts." : "E-mailová aplikace která uživatelům umožňuje číst e-maily ve svých IMAP účtech.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Zde naleznete nastavení pro celou instanci. Nastavení pro jednotlivé uživatele se nachází v aplikaci samotné (levý dolní roh).",
    "Account provisioning" : "Zprovozňování účtů",
    "A provisioning configuration will provision all accounts with a matching email address." : "Nastavení pro zprovoznění služby zprovozní všechny účty se shodující se e-mailovou adresou.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Použití zástupného vyjádření (*) v kolonce pro doménu pro zprovoznění služby vytvoří nastavení, které je uplatňováno na všechny uživatele, pro které neexistuje konkrétnější nastavení.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mechanizmus zprovozňování služby bude upřednostňovat nastavení pro konkrétní doménu před obecným nastavením pro dílčí domény.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Zda má být nové odpovídající nastavení nalezeno poté, co byl uživatel už zprovozněn s jiným nastavením, nová nastavení budou mít přednost a uživatel bude znovuzprovozněn s nastavením.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "U každé z domén je možné mít pouze jedno nastavení pro ni a pouze jedno nastavení pro doménu se zástupným znakem.",
    "These settings can be used in conjunction with each other." : "Tato nastavení je možné použít ve spojení navzájem.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Pokud chcete pro všechny uživatele zprovoznit jednu doménu, použijte zástupný znak (* – hvězdička).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Toto nastavení má největší smysl pokud v organizaci používáte stejnou podpůrnou vrstvu pro uživatelské účty jak pro Nextcloud, tak pro e-mailový server.",
    "Provisioning Configurations" : "Nastavení zprovozňování",
    "Add new config" : "Přidat nové nastavení",
    "Provision all accounts" : "Zprovoznit službu pro všechny účty",
    "Allow additional mail accounts" : "Umožnit ještě další e-mailové účty",
    "Allow additional Mail accounts from User Settings" : "Umožnit v nastaveních pro uživatele zadávat ještě další e-mailové účty",
    "Enable text processing through LLMs" : "Zapnout zpracovávání textu prostřednictvím LLM modelů",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Aplikace E-mail může zpracovávat data uživatele pomocí nastaveného velkého jazykového modelu a poskytovat asistenční funkce jako shrnutí obsahu vláken, inteligentní odpovědi a agendy událostí.",
    "Enable LLM processing" : "Zapnout zpracovávání LLM",
    "Enable classification by importance by default" : "Zapnout rozřazování podle důležitosti coby výchozí stav",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Aplikace E-mail může pomocí strojového učení třídit příchozí zprávy dle důležitosti. Tato funkce je ve výchozím stavu zapnutá, ale je možné ji zde také ve výchozím stavu vypnout. Jednotliví uživatele si ji případně budou moci zapnout ve svých účtech.",
    "Enable classification of important mails by default" : "Zapnout rozpoznávání důležitých e-mailů coby výchozí stav",
    "Anti Spam Service" : "Služba ochrany před nevyžádanou poštou",
    "You can set up an anti spam service email address here." : "Adresu e-mailu služby proti spam zprávám je možné nastavit zde.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Jakýkoli e-mail, označený jako spam bude odeslán na službu proti nevyžádaným zprávám.",
    "Gmail integration" : "Integrace Gmailu",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail uživatelům umožňuje přistupovat k jejich e-mailům prostřednictvím protokolu IMAP. Z bezpečnostních důvodů je tento přístup možné pouze prostřednictvím  OAuth 2.0 spojení nebo Google účtů, které používají dvoufaktorové ověřování a hesla pro aplikace.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Zaregistrovali jste nový identifikátor klienta pro „webovou aplikaci“ v konzoli Google Cloud. Přidejte URL adresu {url} jako pověřenou URI pro přesměrování.",
    "Microsoft integration" : "Integrace Microsoftu",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft umožňuje uživatelům přistupovat k jejich e-mailům prostřednictvím protokolu IMAP. Z důvodů zabezpečení je tento přístup možný pouze připojením ověřeným přes OAuth 2.0.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Na portálu Microsoft Azure Active Directory je třeba zaregistrovat novu aplikaci. Přidejte URL {url} jako URI přeměrování.",
    "Successfully set up anti spam email addresses" : "E-mailové adresy proti spam zprávám úspěšně nastaveny",
    "Error saving anti spam email addresses" : "Chyba při ukládání e-mailový adres proti nevyžádaným zprávám",
    "Successfully deleted anti spam reporting email" : "E-mailová adresa pro hlášení nevyžádaných zpráv úspěšně vymazána",
    "Error deleting anti spam reporting email" : "Chyba při mazání e-mailu pro hlášení nevyžádaných zpráv",
    "Anti Spam" : "Obrana proti nevyžádaným zprávám",
    "Add the email address of your anti spam report service here." : "Sem zadejte e-mailovou adresu služby pro hlášení spam zpráv.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Při použití tohoto nastavení bude pokaždé, když uživatel klikne na „Označit jako nevyžádanou zprávu (spam)“ odeslán e-mail s hlášením na server, určený pro hlášení SPAM zpráv.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Původní zpráva bude přiložena ve formátu „message/rfc822“.",
    "\"Mark as Spam\" Email Address" : "E-mailová adresa pro „Označit jako nevyžádanou zprávu (spam)“",
    "\"Mark Not Junk\" Email Address" : "E-mailová adresa pro „Označit jako korektní zprávu“",
    "Reset" : "Vrátit na výchozí hodnoty",
    "Google integration configured" : "Napojení na Google nastaveno",
    "Could not configure Google integration" : "Nedaří se nastavit napojení na Google",
    "Google integration unlinked" : "Napojení na Google odpojeno",
    "Could not unlink Google integration" : "Nedaří se odpojit napojení na Google",
    "Client ID" : "Identif. klienta",
    "Client secret" : "Klientské tajemství",
    "Unlink" : "Odpojit",
    "Microsoft integration configured" : "Integrace Microsoftu nastavena",
    "Could not configure Microsoft integration" : "Nepodařilo se nastavit integraci Microsoftu",
    "Microsoft integration unlinked" : "Propojení na Microsoft odpojeno",
    "Could not unlink Microsoft integration" : "Nedaří se odpojit propojení Microsoft",
    "Tenant ID (optional)" : "Identifikátor nájemce (volitelné)",
    "Domain Match: {provisioningDomain}" : "Shoda s doménou: {provisioningDomain}",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} šifrování)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} šifrování)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "Nastavení pro „{provisioningDomain}“",
    "Provisioning domain" : "Doména pro zprovozňování služby",
    "Email address template" : "Šablona e-mailové adresy",
    "IMAP" : "IMAP",
    "User" : "Uživatel",
    "Host" : "Hostitel",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Hlavní heslo",
    "Use master password" : "Použít hlavní heslo",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Zapnout napojení na sieve",
    "LDAP aliases integration" : "Napojení na LDAP alternativní názvy",
    "Enable LDAP aliases integration" : "Zapnout napojení na LDAP alternativní názvy",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Napojení na LDAP alternativní názvy čte atributy z nastaveného LDAP adresáře za účelem zprovoznění alternativních e-mailů.",
    "LDAP attribute for aliases" : "LDAP atribut pro alternativní názvy",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Atribut s vícero hodnotami pro zprovoznění alternativních e-mailů. Pro každou z hodnot je vytvořen alternativní název. Alternativní e-maily, které existují v Nextcloud, ale ne v LDAP adresáři, jsou smazány.",
    "Save Config" : "Uložit nastavení",
    "Unprovision & Delete Config" : "Zrušit zprovoznění služby a smazat nastavení",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% a %EMAIL% budou nahrazeny identif. uživatele (UID) a e-mailovou adresou",
    "With the settings above, the app will create account settings in the following way:" : "S výše uvedenými nastaveními aplikace vytvoří nastavení účtu následujícím způsobem:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Je třeba, aby poskytnutý PKCS #12 certifikát obsahoval alespoň jediný certifikát a právě jeden soukromý klíč.",
    "Failed to import the certificate. Please check the password." : "Certifikát se nepodařilo naimportovat. Zkontrolujte heslo.",
    "Certificate imported successfully" : "Certifikát úspěšně naimportován",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Certifikát se nepodařilo naimportovat. Ověřte, že se soukromý klíč shoduje s certifikátem a že není chráněn heslovou frází.",
    "Failed to import the certificate" : "Certifikát se nepodařilo naimportovat",
    "S/MIME certificates" : "S/MIME certifikáty",
    "Certificate name" : "Název certifikátu",
    "E-mail address" : "E-mailová adresa",
    "Valid until" : "Platný do",
    "Delete certificate" : "Smazat certifikát",
    "No certificate imported yet" : "Zatím nenaimportovány žádné certifikáty",
    "Import certificate" : "Naimportovat certifikát",
    "Import S/MIME certificate" : "Naimportovat S/MIME certifikát",
    "PKCS #12 Certificate" : "PKCS #12 certifkát",
    "PEM Certificate" : "PEM certifikát",
    "Certificate" : "Certifikát",
    "Private key (optional)" : "Soukromý klíč (volitelné)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Soukromý klíč je zapotřebí pouze pokud pomocí tohoto certifikátu zamýšlíte posílat podepsané a šifrované e-maily.",
    "Submit" : "Odeslat",
    "Account connected" : "Účet připojen",
    "You can close this window" : "Toto okno je možné zavřít",
    "Connect your mail account" : "Připojit e-mailový účet",
    "To add a mail account, please contact your administrator." : "Pokud chcete přidat e-mailový účet, obraťte se na správce.",
    "All" : "Vše",
    "Drafts" : "Koncepty",
    "Favorites" : "Oblíbené",
    "Priority inbox" : "Přednostní schránka",
    "All inboxes" : "Všechny schránky",
    "Inbox" : "Příchozí zprávy",
    "Junk" : "Spam",
    "Sent" : "Odeslaná",
    "Trash" : "Koš",
    "Connect OAUTH2 account" : "OAUTH2 účet pro připojení",
    "Error while sharing file" : "Chyba při sdílení souboru",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová zpráva\nod {from}","%n nové zprávy\nod {from}","%n nových zpráv\nod {from}","%n nové zprávy\nod {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Je zde už probíhající zpráva. Pokud budete pokračovat, veškeré neuložené změny budou ztraceny!",
    "Discard changes" : "Zahodit změny",
    "Discard unsaved changes" : "Zahodit neuložené změny",
    "Keep editing message" : "Pokračovat v upravování zprávy",
    "Attachments were not copied. Please add them manually." : "Přílohy nebyly zkopírovány. Přidejte je ručně.",
    "Could not create snooze mailbox" : "Nepodařilo se vytvořit schránku pro odložené",
    "Sending message…" : "Odesílání zprávy…",
    "Message sent" : "Zpráva odeslána",
    "Could not send message" : "Zprávu se nepodařilo odeslat",
    "Message copied to \"Sent\" mailbox" : "Zpráva zkopírována do složky „Odeslané“",
    "Could not copy message to \"Sent\" mailbox" : "Nebylo možné zkopírovat do složky „Odeslané“",
    "Could not load {tag}{name}{endtag}" : "Nedaří se načíst {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Došlo k problému s načtením {tag}{name}{endtag}",
    "Could not load your message" : "Vaši zprávu se nedaří načíst",
    "Could not load the desired message" : "Nedaří se načíst vyžádanou zprávu",
    "Could not load the message" : "Zprávu se nedaří načíst",
    "Error loading message" : "Chyba při načtení zprávy",
    "Forwarding to %s" : "Přeposílá se na %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Pokud nebudete v následujících několika sekundách přesměrováni, klikněte sem.",
    "Redirect" : "Přesměrovat",
    "The link leads to %s" : "Odkaz vede na %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
    "Continue to %s" : "Pokračovat na %s",
    "Collapse composer" : "Sbalit editor psaní",
    "Uploading attachments …" : "Nahrávání příloh…",
    "Sending …" : "Odesílání…"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
